#!/bin/bash
#Automatically Created by buildpkg 1.6.1
#Maintainer: Pedro Pinto (pnboy~AT~pinguix.com)

######Begin Redundant Code######################################
check_for_root() {
	if [ "$UID" != "0" ]; then
		echo "You need to be root"
		exit 1
	fi
}

clean_dirs () {
        for COMPLETED in src pkg; do
                if [ -e $COMPLETED ]; then
                        rm -rf $COMPLETED
                fi
        done
}

clean_old_builds () {
	for COMPLETED in $package.{tgz,md5,dep}; do
		if [ "$KEEPDEPFILE" = "1" ] && [ $COMPLETED = $package.dep ]; then
			continue
		elif [ -e $COMPLETED ]; then
			rm -rf $COMPLETED
		fi
	done
	clean_dirs
}

set_pre_permissions() {
	cd $startdir/src
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;
}


check_for_menu_compliance() {
	if [ -d "$startdir/pkg/usr/share/applications" ]; then
		cd $startdir/pkg/usr/share/applications
		for desktop in *.desktop; do
			Icon=$(grep -e "^Icon=" $desktop | sed 's/Icon=//')
			if [[ "$Icon" ]]; then
				if [ ! "$Icon" == "${Icon%.*}" ]; then
					sed '/Icon/s/\..*$//' -i $desktop
					Icon=$(grep -e "^Icon=" $desktop | sed 's/Icon=//')
				fi
				if [ -d "$startdir/pkg/usr/share/pixmaps" ]; then
					cd $startdir/pkg/usr/share/pixmaps
					for pixmaps in *; do
						[ -d $pixmaps ] && continue
						[ ! "${pixmaps##*.}" == "png" -a ! "${pixmaps##*.}" == "svg" ] && continue
				 		if [ "${pixmaps%.*}" == "$Icon" ]; then
				 			DIR=$(file $pixmaps | awk -F, '{print $2}' | sed 's/ //g')
							[ o"$DIR" == "o" ] && DIR="scalable"
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $pixmaps $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							if [[ ! "$(ls $startdir/pkg/usr/share/pixmaps)" ]]; then
								rm -rf $startdir/pkg/usr/share/pixmaps
							fi
						fi
					done
				fi
				if [ -d "$startdir/pkg/usr/share/icons" ]; then
					cd $startdir/pkg/usr/share/icons
					for icons in *; do
				 		if [ "${icons%.*}" == "$Icon" ]; then
							[ ! "${pixmaps##*.}" == "png" -a ! "${pixmaps##*.}" == "svg" ] && continue
				 			DIR=$(file $icons | awk -F, '{print $2}' | sed 's/ //g')
							[ o"$DIR" == "o" ] && DIR="scalable"
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $icons $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
						fi
					done
				fi
			fi
		done
	fi
}


gzip_man_and_info_pages() {
	for DOCS in man info; do
		if [ -d "$startdir/pkg/usr/share/$DOCS" ]; then
			mv $startdir/pkg/usr/share/$DOCS $startdir/pkg/usr/$DOCS
			if [[ ! "$(ls $startdir/pkg/usr/share)" ]]; then
				rm -rf $startdir/pkg/usr/share
			fi
		fi
		if [ -d "$startdir/pkg/usr/$DOCS" ]; then
			# I've never seen symlinks in info pages....
			if [ "$DOCS" == "man" ]; then
				(cd $startdir/pkg/usr/$DOCS
				for manpagedir in $(find . -type d -name "man*" 2> /dev/null) ; do
					( cd $manpagedir
					for eachpage in $( find . -type l -maxdepth 1 2> /dev/null) ; do
						ln -s $( readlink $eachpage ).gz $eachpage.gz
						rm $eachpage
					done )
				done)
			fi
			find $startdir/pkg/usr/$DOCS -type f -exec gzip -9 '{}' \;
		fi
	done
}

set_post_permissions() {
	for DIRS in usr/share/icons usr/doc; do
		if [ -d "$startdir/pkg/$DIRS" ]; then
			if [ "$DIRS" == "usr/doc" ]; then
				find $startdir/pkg/$DIRS -type f -exec chmod 644 {} \;
				find $startdir/pkg/$DIRS -type d -exec chmod 755 {} \;
			fi
		fi
		[ -d $startdir/pkg/$DIRS ] && chown root:root -R $startdir/pkg/$DIRS
	done
	[ -d $startdir/pkg/usr/bin ] && find $startdir/pkg/usr/bin -user root -group bin -exec chown root:root {} \;
}

copy_build_script() {
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver/
	cp $startdir/build-$pkgname.sh $startdir/pkg/usr/src/$pkgname-$pkgver/build-$pkgname.sh
	[ -f $startdir/ZENBUILD ] && cp $startdir/ZENBUILD $startdir/pkg/usr/src/$pkgname-$pkgver/ZENBUILD
}

create_package() {
	ls -lR $startdir/pkg
	cd $startdir/pkg
	/sbin/makepkg -l y -c n $startdir/$package.tgz
	cd $startdir
	md5sum $package.tgz > $startdir/$package.md5
}

strip_binaries() {
	cd $startdir/pkg
	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
}
#########End Redundant Code#####################################
#########Begin Non Redundant Code##############################

prepare_directory() {
	mkdir $startdir/src
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver
	for SOURCES in ${source[@]}; do
		protocol=$(echo $SOURCES | sed 's|:.*||')
	        file=$(basename $SOURCES | awk -F= '{print $NF}')
		if [ ! -f "$file" ]; then
			if [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
				echo -e "\nDownloading $(basename $SOURCES)\n"
        	                wget $SOURCES -O $file
				if [ ! "$?" == "0" ]; then
					echo "Download failed"
					exit 2
				fi 
			else
				echo "$SOURCES does not appear to be a url nor is it in the directory"
				exit 2
			fi
		fi
		cp -R $file $startdir/src
		if ! [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
			cp -R $startdir/$(basename $SOURCES) $startdir/pkg/usr/src/$pkgname-$pkgver/
		fi
		if [ "${SOURCES##*.}" == "desktop" ]; then
			[[ "$(grep -e "^Categories=[a-zA-Z]*;" $(basename $SOURCES))" ]] && install -D $startdir/$(basename $SOURCES) /home/packages/iceweasel/pkg/usr/share/applications/$(basename $SOURCES)
		fi
	done
}

extract_source() {
	cd $startdir/src
	if [[ "$(ls $startdir/src)" ]]; then	
		for FILES in ${source[@]}; do
	        	FILES="$(basename $FILES | awk -F= '{print $NF}')"
			file_type=$(file -biz "$FILES")
			unset cmd
			case "$file_type" in
				*application/x-tar*)
					cmd="tar -xf" ;;
				*application/x-zip*)
					cmd="unzip" ;;
				*application/x-gzip*)
					cmd="gunzip -d -f" ;;
				*application/x-bzip*)
					cmd="bunzip2 -f" ;;
			esac
			if [ "$cmd" != "" ]; then
				echo "$cmd $FILES"
	        	        $cmd $FILES
			fi
		done
	elif [ ! "$source" ]; then
		echo -n "" # lame fix
	else
		echo "no files in the src directory $startdir/src"
		exit 2
	fi
}

build() {
	cd $startdir/src/mozilla
	sh $startdir/src/remove.nonfree
	cp $startdir/src/*.png zenwalk/branding
	cp $startdir/src/*.png zenwalk/branding/content
	cp $startdir/src/*.xpm zenwalk/branding
#cat <<'EOF' >>.mozconfig
#ac_add_options --prefix=/usr
#ac_add_options --mandir=/usr/man
#ac_add_options --infodir=/usr/info
#ac_add_options --enable-optimize="${CFLAGS} -freorder-blocks -fno-reorder-functions -gstabs+"
#ac_add_options --with-distribution-id=Zenwalk
#ac_add_options --disable-accessibility
#ac_add_options --disable-calendar
#ac_add_options --disable-chatzilla
#ac_add_options --disable-composer
#ac_add_options --disable-crashreporter
#ac_add_options --disable-debug
#ac_add_options --disable-freetype2
#ac_add_options --disable-installer
#ac_add_options --disable-jsd
#ac_add_options --disable-ldap
#ac_add_options --disable-logging
#ac_add_options --disable-mailnews
#ac_add_options --disable-mathml
#ac_add_options --disable-negotiateauth
#ac_add_options --disable-profilesharing
#ac_add_options --disable-tests
#ac_add_options --disable-toolkit-qt
#ac_add_options --disable-updater
#ac_add_options --disable-xinerama
#ac_add_options --disable-xprint
#ac_add_options --enable-application=browser
#ac_add_options --enable-crypto
#ac_add_options --enable-default-toolkit=cairo-gtk2
#ac_add_options --enable-extensions="default,spellcheck,cookie,xml-rpc,xmlextras,pref,universalchardet,webservices"
#ac_add_options --enable-gnomevfs
#ac_add_options --enable-single-profile
#ac_add_options --enable-static 
#ac_add_options --enable-strip
#ac_add_options --enable-system-cairo
#ac_add_options --enable-xft
#ac_add_options --with-branding=zenwalk/branding
#ac_add_options --with-pthreads
#ac_add_options --with-system-jpeg
#ac_add_options --with-system-nspr
#ac_add_options --with-system-nss
#ac_add_options --with-system-png
#ac_add_options --with-system-zlib
#ac_add_options --with-user-appdir=.mozilla
#ac_cv_visibility_pragma=no
#EOF
cat <<'EOF' >>.mozconfig
ac_add_options --prefix=/usr
ac_add_options --mandir=/usr/man
ac_add_options --infodir=/usr/info
ac_add_options --enable-optimize="${CFLAGS} -freorder-blocks -fno-reorder-functions -gstabs+"
ac_add_options --with-distribution-id=Zenwalk
ac_add_options --disable-accessibility
ac_add_options --disable-calendar
ac_add_options --disable-chatzilla
ac_add_options --disable-debug
ac_add_options --disable-debug-modules
ac_add_options --disable-gnomeui
ac_add_options --disable-composer
ac_add_options --disable-dtd-debug
ac_add_options --disable-freetype2
ac_add_options --disable-installer
ac_add_options --disable-ldap
ac_add_options --disable-mailnews
ac_add_options --disable-negotiateauth
ac_add_options --disable-profilesharing
ac_add_options --disable-shared
ac_add_options --disable-tests
ac_add_options --disable-toolkit-qt
ac_add_options --disable-xprint
ac_add_options --enable-application=browser
ac_add_options --enable-canvas
ac_add_options --enable-cookies
ac_add_options --enable-crypto
ac_add_options --enable-default-toolkit=cairo-gtk2
ac_add_options --enable-extensions="default,spellcheck,cookie,xml-rpc,xmlextras,pref,universalchardet,webservices"
ac_add_options --enable-gnomevfs
ac_add_options --enable-image-encoder=all
ac_add_options --enable-image-decoder=all
ac_add_options --enable-mathml
ac_add_options --enable-pango
ac_add_options --enable-postscript
ac_add_options --enable-reorder
ac_add_options --enable-safe-browsing
ac_add_options --enable-single-profile
#ac_add_options --enable-static
ac_add_options --enable-storage
ac_add_options --enable-svg
ac_add_options --enable-system-cairo
ac_add_options --enable-toolkit-cairo-gtk2
ac_add_options --enable-url-classifier
ac_add_options --enable-view-source
ac_add_options --enable-xft
ac_add_options --enable-xinerama
ac_add_options --enable-xpctools
ac_add_options --with-branding=zenwalk/branding
ac_add_options --with-pthreads
ac_add_options --with-system-jpeg
#ac_add_options --with-system-nspr
#ac_add_options --with-system-nss
#ac_add_options --with-system-png
ac_add_options --with-system-zlib
ac_add_options --with-user-appdir=.mozilla
ac_cv_visibility_pragma=no
EOF
	export MOZ_PROJECT=browser
	export MOZILLA_OFFICIAL=1
	export BUILD_OFFICIAL=1
#	make -f client.mk build || return 1
	export MAKEFLAGS="-j1"
	./configure
	make || return 1
	(cd embedding/config
	make )
	make DESTDIR=$startdir/pkg install MOZ_PKG_APPNAME="iceweasel" EXCLUDE_NSPR_LIBS=1

	# build a iceweasel-devel package
	package2=$pkgname-devel-$pkgver-$arch-$zenver.$pkgrel
	[ -d $startdir/pkg2 ] && rm -rf $startdir/pkg2
	mkdir -p $startdir/pkg2/usr/{share,lib}
	mv $startdir/pkg/usr/share/idl $startdir/pkg2/usr/share
	mv $startdir/pkg/usr/include $startdir/pkg2/usr/
	mv $startdir/pkg/usr/lib/pkgconfig $startdir/pkg2/usr/lib/
	mv $startdir/pkg/usr/lib/firefox-devel-$pkgver $startdir/pkg2/usr/lib/
	# why should it need over 400MB(uncompressed) of SDK!?!
	rm -rf $startdir/pkg2/usr/lib/firefox-devel-$pkgver/sdk
        cd $startdir/pkg2
	mkdir -p $startdir/pkg2/install/
        cat << EOF > $startdir/pkg2/install/slack-desc
$pkgname-devel: $pkgname-devel (Development files for iceweasel)
$pkgname-devel: 
$pkgname-devel: Development files for iceweasel.
EOF
        /sbin/makepkg -l y -c n $startdir/$package2.tgz
        cd $startdir
        md5sum $package2.tgz > $startdir/$package2.md5
	#empty dep file
	echo "">$startdir/$package2.dep
	rm -rvf $startdir/pkg2
	unset package2

	mkdir -p $startdir/pkg/usr/lib/mozilla/plugins
	mkdir -p $startdir/pkg/usr/bin
	cp $startdir/src/iceweasel $startdir/pkg/usr/bin
	chmod +x $startdir/pkg/usr/bin/iceweasel
	# compability link
	( cd $startdir/pkg/usr/bin ; ln -sf iceweasel firefox )
	# add symlink to fix plugin-dirs
	# and move /usr/lib so we don't break plugins with version updates
	( cd $startdir/pkg/usr/lib/; mv firefox-$pkgver $pkgname ; ln -s $pkgname firefox ; ln -s $pkgname $pkgname-$pkgver )
	#for java plugin
	( cd $startdir/pkg/usr/lib/$pkgname ; rm -rf plugins )
	( cd $startdir/pkg/usr/lib/$pkgname ; ln -sf ../mozilla/plugins plugins )
	# Replace included dictionaries with a link to zenwalk's dictionaries
	( cd $startdir/pkg/usr/lib/$pkgname
	ln -s firefox-bin iceweasel-bin
	rm -rf dictionaries
	ln -s ../../share/myspell dictionaries 
	# compability link for run-mozilla.sh
	ln -s run-mozilla.sh run-iceweasel.sh
	# default icons for application
	mkdir -p chrome/icons/default/
	cp $startdir/src/*.xpm chrome/icons/default/
	cp $startdir/src/*.xpm icons/
	cp $startdir/src/document.png icons/
	)
	mkdir -p $startdir/pkg/usr/share/icons/hicolor/{16x16,32x32,48x48,64x64,128x128}/apps/
	size="16x16 32x32 48x48 64x64 128x128"
	for i in $size; do
		cp $startdir/src/iceweasel_${i%x*}.png $startdir/pkg/usr/share/icons/hicolor/$i/apps/iceweasel.png
	done
	# fix browser.jar
	(cd $startdir/src/
	mkdir -p browser
	cd browser
	jar xf $startdir/pkg/usr/lib/$pkgname/chrome/browser.jar
	cp $startdir/src/about.png $startdir/src/aboutCredits.png $startdir/src/aboutFooter.png $startdir/src/icon48.png $startdir/src/icon64.png $startdir/src/browser/content/branding
	jar cfM $startdir/pkg/usr/lib/$pkgname/chrome/browser.jar .
	)
	# remove inspector extension
	rm -rf $startdir/pkg/usr/lib/$pkgname/extensions/inspector*
	if [ -f $startdir/src/prefs.js ]; then
		cp $startdir/src/prefs.js $startdir/pkg/usr/lib/$pkgname/defaults/profile/prefs.js
	fi
	if [ -f $startdir/src/mimeTypes.rdf ]; then
		cp $startdir/src/mimeTypes.rdf $startdir/pkg/usr/lib/$pkgname/defaults/profile/mimeTypes.rdf
	fi
	# add zenwalk plugins for searchbox
	if [ -f $startdir/src/zenwalk.src ]; then
		if [ -d $startdir/pkg/usr/lib/$pkgname/searchplugins/ ]; then
			cp $startdir/src/zenwalk.src $startdir/pkg/usr/lib/$pkgname/searchplugins/zenwalk.src
			cp $startdir/src/zenwalk.png $startdir/pkg/usr/lib/$pkgname/searchplugins
		fi
	fi
	# disable for now
	#if [ -f $startdir/src/classic_firefox.jar ]; then
	#	cp $startdir/src/classic_firefox.jar $startdir/pkg/usr/lib/$pkgname/chrome/classic.jar
	#fi
	# patches for locales
	cd $startdir/pkg/usr/lib/$pkgname/
	rm defaults/pref/firefox-branding.js
	echo 'browser.startup.homepage=http://www.zenwalk.org/' > browserconfig.properties
	sed -i -e '/pref("general.useragent.locale", "en-US");/d' defaults/pref/firefox-l10n.js
	sed -i -e '/pref("general.useragent.locale", "en-US");/d' defaults/pref/firefox.js
	sed -i -e "s|pref(\"general.useragent.extra.firefox\", \"BonEcho/$pkgver\");|pref(\"general.useragent.extra.firefox\", \"IceWeasel/$pkgver\");|g" defaults/pref/firefox.js
	sed -i -e 's|pref("general.useragent.locale", "chrome://navigator/locale/navigator.properties");|pref("general.useragent.locale", "chrome://global/locale/intl.properties");|g' greprefs/all.js
	sed -i -e 's|pref("general.useragent.contentlocale", "chrome://navigator-region/locale/region.properties");|pref("general.useragent.contentlocale", "chrome://browser-region/locale/region.properties");|g' greprefs/all.js
	sed -i -e 's/pref("intl.locale.matchOS",                 false);/pref("intl.locale.matchOS",                 true);/g' greprefs/all.js
	echo "// Zenwalk package version" > defaults/pref/vendor.js
	echo "pref(\"general.useragent.extra.firefoxComment\",\"(Zenwalk GNU Linux)\");" >> defaults/pref/vendor.js
	echo 'pref("browser.EULA.override", true);' >> defaults/pref/vendor.js
	mkdir -p $startdir/pkg/etc/ld.so.conf.d/
	echo "/usr/lib/iceweasel" > $startdir/pkg/etc/ld.so.conf.d/iceweasel.conf
	echo 'pref("network.protocol-handler.app.mailto", "icedove");' >> greprefs/all.js
	mkdir -p $startdir/pkg/usr/man/man1
	cp $startdir/src/iceweasel.1 $startdir/pkg/usr/man/man1
} 

create_slackdesc() {
mkdir $startdir/pkg/install
cat <<"EODESC" >$startdir/pkg/install/slack-desc
iceweasel: iceweasel (Iceweasel web browser)
iceweasel: 
iceweasel: IceWeasel is the GNU version of the Firefox browser. Its main
iceweasel: advantage is an ethical one: it is entirely free software. While the
iceweasel: source code from the Mozilla project is free software, the binaries
iceweasel: that they release include additional non-free software. Also, they
iceweasel: distribute non-free software as plug-ins. (IceWeasel does keep the
iceweasel: triple licensing used by Firefox to facilitate the reuse of code.)
iceweasel: 
iceweasel: 
iceweasel: 
EODESC
}

detect_dependencies() {
	echo "Detecting dependencies..."
	depends=$(requiredbuilder -z $startdir/$package.tgz)
	
	depstring=$depends
	unset FIRST
	for deps in $(echo "${depstring}" | sed 's/,/\n/g' | sort -u); do
		if [[ ! "$FIRST" ]]; then
			finaldeps=$deps,
			FIRST='1'
			continue
		fi
		finaldeps=${finaldeps}${deps},
	done
	echo "$finaldeps" | sed -e 's/^,//' -e 's/,$//' > $startdir/$package.dep
}
create_source_file(){
	[ -f $package.src ] && rm $package.src
	if [ ! -z $sourcetemplate ]; then
		echo $sourcetemplate/ZENBUILD >> $package.src
		echo $sourcetemplate/build-$pkgname.sh >> $package.src
	else
		echo ZENBUILD >> $package.src
		echo build-$pkgname.sh >> $package.src
	fi
	for SOURCES in ${source[@]}; do
		protocol=$(echo $SOURCES | sed 's|:.*||')
		if ! [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
			if [ ! -z $sourcetemplate ]; then
				echo $sourcetemplate/$(basename $SOURCES) >> $package.src
			else
				echo $(basename $SOURCES) >> $package.src
			fi
		else
			echo $SOURCES >> $package.src
		fi
	done
}
post_checks(){
	# Ideas taken from src2pkg :)
	if [ -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
		for DIRS in usr/doc/$pkgname-$pkgver usr/doc; do
			cd $startdir/pkg/$DIRS
			if [[ $(find . -type f) = "" ]] ; then
				cd ..
				rmdir $DIRS
			fi
		done
	fi
	# if the docs weren't deleted ...
	if [ -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
		cd $startdir/pkg/usr/doc/$pkgname-$pkgver
		#remove zero lenght files
		if [[ $(find . -type f -size 0) ]]; then
			echo "Removing some zero lenght files"
			find . -type f -size 0 -exec rm -f {} \;
		fi
	fi
	# check if we need to add code to handle info pages
	if [[ -d $startdir/pkg/usr/info ]] && [[ ! $(grep install-info $startdir/pkg/install/doinst.sh &> /dev/null) ]] ; then
		echo "Found info files - Adding install-info command to doinst.sh"
		INFO_LIST=$(ls -1 $startdir/pkg/usr/info)
		echo "" >> $startdir/pkg/install/doinst.sh
		echo "if [ -x usr/bin/install-info ] ; then" >> $startdir/pkg/install/doinst.sh
		for page in $(echo $INFO_LIST) ; do
			echo " usr/bin/install-info --info-dir=usr/info usr/info/$page 2>/dev/null" >> $startdir/pkg/install/doinst.sh
		done
		echo "fi" >> $startdir/pkg/install/doinst.sh
	fi
	# add files in etc to dotnew (if it wasn't defined)
	if [ ! -z $NOAUTODOTNEW ]; then
		if [ -d $startdir/pkg/etc ]; then
			cd $startdir/pkg/
			for conf in $(find ./etc -type f) ; do
				conf=${conf: 2}
				dotnew=( "${dotnew[@]}" "$conf" )
			done
		fi
	fi
	if [[ "$dotnew" ]]; then
        for files in ${dotnew[@]} ; do
                fullfile="${startdir}/pkg/${files}"
                if [ -e "$fullfile" ]; then
                        mv $fullfile ${fullfile}.new
                else
                        echo "$fullfile was not found"
                        exit 2
                fi
        done
        cat<<"EODOTNEW" >>$startdir/pkg/install/doinst.sh
#Added by buildpkg 1.6.1
dotnew() {
        NEW="${1}.new"
        OLD="$1"
        if [ ! -e $OLD ]; then
                mv $NEW $OLD
        elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
                rm $NEW
        fi
}
EODOTNEW

for i in ${dotnew[@]}; do
echo "dotnew $i" >> $startdir/pkg/install/doinst.sh
done
fi
	[[ -e $startdir/pkg/usr/info/dir ]] && rm -f $startdir/pkg/usr/info/dir


}

####End Non Redundant Code############################

#Variables

startdir=$(pwd)
SRC=$startdir/src
PKG=$startdir/pkg

pkgname=iceweasel
pkgver=3.0.5
pkgrel=1
zenver=54
arch=i486
package=$pkgname-$pkgver-$arch-$zenver.$pkgrel
source=("http://releases.mozilla.org/pub/mozilla.org/firefox/releases/3.0.5/source/firefox-3.0.5-source.tar.bz2" "http://pnboy.pinguix.com/my_packages/zenwalk/iceweasel/3.0.5/mimeTypes.rdf.gz" "http://pnboy.pinguix.com/my_packages/zenwalk/iceweasel/3.0.5/prefs.js.gz" "http://pnboy.pinguix.com/my_packages/zenwalk/iceweasel/3.0.5/zenwalk.png" "http://pnboy.pinguix.com/my_packages/zenwalk/iceweasel/3.0.5/zenwalk.src.gz" "http://pnboy.pinguix.com/my_packages/zenwalk/iceweasel/3.0.5/iceweasel.desktop" "http://pnboy.pinguix.com/my_packages/zenwalk/iceweasel/3.0.5/branding.tar.bz2" "http://pnboy.pinguix.com/my_packages/zenwalk/iceweasel/3.0.5/iceweasel" "http://pnboy.pinguix.com/my_packages/zenwalk/iceweasel/3.0.5/iceweasel.1" "http://pnboy.pinguix.com/my_packages/zenwalk/iceweasel/3.0.5/remove.nonfree")
sourcetemplate=http://pnboy.pinguix.com/my_packages/zenwalk/iceweasel/3.0.5
docs=()
export CFLAGS="-O2 -march=i486 -mtune=i686"
export CXXFLAGS="-O2 -march=i486 -mtune=i686"

#Execution

check_for_root
clean_old_builds
prepare_directory
extract_source
set_pre_permissions
build
if [ ! "$?" = "0" ]; then
	echo "build() failed."
	exit 2
fi
create_slackdesc
post_checks
check_for_menu_compliance
strip_binaries
gzip_man_and_info_pages
set_post_permissions
copy_build_script
create_package
create_source_file
detect_dependencies
echo "Package has been built."
echo "Cleaning pkg and src directories"
clean_dirs
